@@ -1,6 +1,6 @@
-use clap::{AppSettings, Parser};
+use clap::Parser;
 use reveal_yaml::*;
-use std::io::Error;
+use std::{io::Error, path::PathBuf};
 
 #[derive(Parser)]
 #[clap(
@@ -8,7 +8,7 @@ use std::io::Error;
     version = env!("CARGO_PKG_VERSION"),
     author = env!("CARGO_PKG_AUTHORS"),
     about = env!("CARGO_PKG_DESCRIPTION"),
-    setting = AppSettings::ArgRequiredElseHelp
+    setting = clap::AppSettings::ArgRequiredElseHelp
 )]
 struct Entry {
     #[clap(subcommand)]
@@ -22,19 +22,19 @@ enum Subcommand {
     /// Create a new project and its directory
     New {
         /// Project dir
-        dir: String,
+        dir: PathBuf,
     },
-    /// Create a new project from exist directory
+    /// Create a new project from an existing directory
     Init {
         /// Project dir
         #[clap(default_value = ".")]
-        dir: String,
+        dir: PathBuf,
     },
     /// Serve the current project
     Serve {
         /// Project dir
         #[clap(default_value = ".")]
-        dir: String,
+        dir: PathBuf,
         /// Port number
         #[clap(long, default_value = "8080")]
         port: u16,
@@ -44,12 +44,15 @@ enum Subcommand {
         /// Edit mode, watch the state of the project
         #[clap(short, long)]
         edit: bool,
+        /// Open the browser.
+        #[clap(long)]
+        open: bool,
     },
     /// Format the current project
     Fmt {
         /// Project dir
         #[clap(default_value = ".")]
-        dir: String,
+        dir: PathBuf,
         /// Project filename
         #[clap(short, long, default_value = "ROOT")]
         name: String,
@@ -60,7 +63,7 @@ enum Subcommand {
     /// Pack the current project
     Pack {
         /// Project dir
-        dir: String,
+        dir: PathBuf,
         /// Project filename
         #[clap(short, long, default_value = ROOT)]
         name: String,
@@ -70,20 +73,20 @@ enum Subcommand {
     },
 }
 
-#[actix_web::main]
-async fn main() -> Result<(), Error> {
+fn main() -> Result<(), Error> {
     let args = Entry::parse();
     match args.subcommand {
-        Subcommand::Update => update().await,
-        Subcommand::New { dir } => blank::<_, true>(dir),
-        Subcommand::Init { dir } => blank::<_, false>(dir),
+        Subcommand::Update => update(),
+        Subcommand::New { dir } => blank(dir, true),
+        Subcommand::Init { dir } => blank(dir, false),
         Subcommand::Serve {
             dir,
             port,
             name,
             edit,
-        } => serve(port, dir, &name, edit).await,
+            open,
+        } => serve(port, dir, &name, edit, open),
         Subcommand::Fmt { dir, name, dry_run } => fmt(dir, dry_run, &name),
-        Subcommand::Pack { dir, name, out } => pack(dir, out, &name).await,
+        Subcommand::Pack { dir, name, out } => pack(dir, out, &name),
     }
 }
