@@ -1,7 +1,7 @@
 use self::edit_mode::ServerMonitor;
 use crate::{
-    loader::loader,
     pack::{extract, listdir},
+    project::load,
     update::archive,
 };
 use actix_files::Files;
@@ -30,14 +30,14 @@ struct Cache {
 }
 
 /// Launch function.
-pub async fn serve<P>(port: u16, path: P, project: &str, edit: bool) -> Result<()>
+pub fn serve<P>(port: u16, path: P, project: &str, edit: bool, open: bool) -> Result<()>
 where
     P: AsRef<Path>,
 {
     set_current_dir(path.as_ref())?;
     let temp = TempDir::new().map_err(|s| Error::new(ErrorKind::PermissionDenied, s))?;
     // Expand Reveal.js
-    extract(temp.path()).await?;
+    extract(temp.path())?;
     // Start server
     let archive = temp.path().join(archive!());
     println!("Serve at: http://localhost:{}/", port);
@@ -51,12 +51,15 @@ where
         doc: if edit {
             String::new()
         } else {
-            loader(&read_to_string(project)?, "/static/", edit)?
+            load(&read_to_string(project)?, "/static/", edit)?
         },
-        help_doc: loader(HELP_DOC, "/static/", false)?,
+        help_doc: load(HELP_DOC, "/static/", false)?,
         reload: edit,
     });
-    HttpServer::new(move || {
+    if open {
+        webbrowser::open(&format!("http://localhost:{}/", port))?;
+    }
+    let server = HttpServer::new(move || {
         let app = App::new()
             .app_data(cache.clone())
             .app_data(Data::new(ServerMonitor::new(cache.project.clone())))
@@ -72,6 +75,6 @@ where
         })
     })
     .bind(("localhost", port))?
-    .run()
-    .await
+    .run();
+    actix_web::rt::System::new().block_on(server)
 }
